[gtk+] Miscellaneous property string fixes



commit ba158a24fe150b6535b376d3ba2696d4eb581466
Author: Philip Withnall <philip tecnocode co uk>
Date:   Sat Aug 28 13:51:41 2010 +0100

    Miscellaneous property string fixes

 gdk/gdkdevice.c        |   10 +++++-----
 gtk/gtkbbox.c          |    4 ++--
 gtk/gtktoolitemgroup.c |    2 +-
 3 files changed, 8 insertions(+), 8 deletions(-)
---
diff --git a/gdk/gdkdevice.c b/gdk/gdkdevice.c
index 8c03509..19fa1dc 100644
--- a/gdk/gdkdevice.c
+++ b/gdk/gdkdevice.c
@@ -95,7 +95,7 @@ gdk_device_class_init (GdkDeviceClass *klass)
 				   PROP_DISPLAY,
 				   g_param_spec_object ("display",
                                                         P_("Device Display"),
-                                                        P_("Display to which the device belongs to"),
+                                                        P_("Display which the device belongs to"),
                                                         GDK_TYPE_DISPLAY,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |
                                                         G_PARAM_STATIC_STRINGS));
@@ -110,7 +110,7 @@ gdk_device_class_init (GdkDeviceClass *klass)
 				   PROP_DEVICE_MANAGER,
 				   g_param_spec_object ("device-manager",
                                                         P_("Device manager"),
-                                                        P_("Device manager to which the device belongs to"),
+                                                        P_("Device manager which the device belongs to"),
                                                         GDK_TYPE_DEVICE_MANAGER,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |
                                                         G_PARAM_STATIC_STRINGS));
@@ -148,7 +148,7 @@ gdk_device_class_init (GdkDeviceClass *klass)
   /**
    * GdkDevice:associated-device:
    *
-   * Associated pointer or keyboard to this device, if any. Devices of type #GDK_DEVICE_TYPE_MASTER
+   * Associated pointer or keyboard with this device, if any. Devices of type #GDK_DEVICE_TYPE_MASTER
    * always come in keyboard/pointer pairs. Other device types will have a %NULL associated device.
    *
    * Since: 3.0
@@ -157,7 +157,7 @@ gdk_device_class_init (GdkDeviceClass *klass)
 				   PROP_ASSOCIATED_DEVICE,
 				   g_param_spec_object ("associated-device",
                                                         P_("Associated device"),
-                                                        P_("Associated pointer or keyboard to this device"),
+                                                        P_("Associated pointer or keyboard with this device"),
                                                         GDK_TYPE_DEVICE,
                                                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
   /**
@@ -202,7 +202,7 @@ gdk_device_class_init (GdkDeviceClass *klass)
   g_object_class_install_property (object_class,
 				   PROP_HAS_CURSOR,
 				   g_param_spec_boolean ("has-cursor",
-                                                         P_("Whether the device has cursor"),
+                                                         P_("Whether the device has a cursor"),
                                                          P_("Whether there is a visible cursor following device motion"),
                                                          FALSE,
                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |
diff --git a/gtk/gtktoolitemgroup.c b/gtk/gtktoolitemgroup.c
index 26a0815..b54c22f 100644
--- a/gtk/gtktoolitemgroup.c
+++ b/gtk/gtktoolitemgroup.c
@@ -1577,7 +1577,7 @@ gtk_tool_item_group_class_init (GtkToolItemGroupClass *cls)
   g_object_class_install_property (oclass, PROP_COLLAPSED,
                                    g_param_spec_boolean ("collapsed",
                                                          P_("Collapsed"),
-                                                         P_("Wether the group has been collapsed and items are hidden"),
+                                                         P_("Whether the group has been collapsed and items are hidden"),
                                                          DEFAULT_COLLAPSED,
                                                          GTK_PARAM_READWRITE));
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gtk/gtkbbox.c b/gtk/gtkbbox.c
index f0c893c..891326d 100644
--- a/gtk/gtkbbox.c
+++ b/gtk/gtkbbox.c
@@ -172,7 +172,7 @@ gtk_button_box_class_init (GtkButtonBoxClass *class)
                                    PROP_LAYOUT_STYLE,
                                    g_param_spec_enum ("layout-style",
                                                       P_("Layout style"),
-                                                      P_("How to layout the buttons in the box. Possible values are spread, edge, start and end"),
+                                                      P_("How to lay out the buttons in the box. Possible values are: spread, edge, start and end"),
                                                       GTK_TYPE_BUTTON_BOX_STYLE,
                                                       DEFAULT_LAYOUT_STYLE,
                                                       GTK_PARAM_READWRITE));
@@ -323,7 +323,7 @@ gtk_button_box_set_layout (GtkButtonBox      *widget,
  *
  * Retrieves the method being used to arrange the buttons in a button box.
  *
  * Returns: the method used to layout buttons in @widget.
  */
 GtkButtonBoxStyle
 gtk_button_box_get_layout (GtkButtonBox *widget)
@@ -323,7 +323,7 @@ gtk_button_box_set_layout (GtkButtonBox      *widget,
  * Retrieves the method being used to arrange the buttons in a button box.
  *
- * Returns: the method used to layout buttons in @widget.
+ * Returns: the method used to lay out buttons in @widget.
  */
 GtkButtonBoxStyle